@@ -1,7 +1,7 @@
 use 5.006;
 package WWW::REST;
-$WWW::REST::VERSION = '0.011';
-
+# $WWW::REST::VERSION = '0.011';
+$WWW::REST::VERSION = '0.021';
 use strict;
 use vars '$AUTOLOAD';
 
@@ -118,7 +118,7 @@ WWW::REST - Base class for REST resources
 
 =head1 VERSION
 
-version 0.02
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -141,7 +141,7 @@ version 0.02
 =head1 DESCRIPTION
 
 This module is a mixin of L<URI>, L<LWP::UserAgent>, L<HTTP::Response>
-and an user-defined dispatch module.  It is currently just a proof of
+and a user-defined dispatch module.  It is currently just a proof of
 concept for a resource-oriented API framework, also known as B<REST>
 (Representational State Transfer).
 
@@ -149,21 +149,20 @@ concept for a resource-oriented API framework, also known as B<REST>
 
 =head1 VERSION
 
-This document describes version 0.011 of WWW::REST, released
-May 2, 2015.
+version 0.021
 
 =head1 METHODS
 
 =head2 WWW::REST->new($string, @args)
 
-Constructor (class method).  Takes an URL string, returns a WWW::REST
+Constructor (class method).  Takes a URL string, returns a WWW::REST
 object.  The optional arguments are passed to LWP::UserAgent->new.
 
 =head2 $url->url($string)
 
-Constructor (instance method).  Takes an URL string, which may be
+Constructor (instance method).  Takes a URL string, which may be
 relative to the object's URL.  Returns a WWW::REST object, which
-inherits the same ua and dispatcher.
+inherits the same ua (= user-agent) and dispatcher.
 
 =head2 $url->dispatch($coderef)
 
@@ -174,11 +173,11 @@ Gets or sets the dispatch code reference.
 Gets or sets the embedded URI, LWP::UserAgent and HTTP::Response
 objects respectively.  Note that C<$url> can automatically delegate
 method calls to embedded objects, so normally you won't need to call
-those method explicitly.
+those methods explicitly.
 
 =head2 $url->get(%args), $url->post(%args), $url->head(%args), $url->put(%args), $url->delete(%args), $url->options(%args), $url->trace(%args), $url->connect(%args)
 
-Performs the corresponding operation to the object; returns the object
+Performs the corresponding operation on the object; returns the object
 itself.  If C<dispatch> is set to a code reference, the object is passed
 to it instead, and returns its return value.
 
@@ -216,7 +215,7 @@ directory.
 =head1 NOTES
 
 This module is considered highly experimental and essentially
-unmaintained; it's kept on CPAN for historical purposes.
+unmaintained; it's kept on CPAN for historical reasons.
 
 =head1 SEE ALSO
 
@@ -226,6 +225,8 @@ L<URI>, L<LWP::UserAgent>, L<HTTP::Response>
 
 Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
+Shlomi Fish, L<http://www.shlomifish.org/> .
+
 =head1 CC0 1.0 Universal
 
 To the extent possible under law, 唐鳳 has waived all copyright and related
